@@ -3,7 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * Author: Alexander Mikhaylenko <alexander.mikhaylenko@puri.sm>
+ * Author: Alice Mikhaylenko <alice.mikhaylenko@puri.sm>
  */
 
 #include "config.h"
@@ -105,6 +105,7 @@ adw_bin_class_init (AdwBinClass *klass)
   object_class->set_property = adw_bin_set_property;
 
   widget_class->compute_expand = adw_widget_compute_expand;
+  widget_class->focus = adw_widget_focus_child;
 
   /**
    * AdwBin:child: (attributes org.gtk.Property.get=adw_bin_get_child org.gtk.Property.set=adw_bin_set_child)
@@ -195,6 +196,9 @@ adw_bin_set_child (AdwBin    *self,
   g_return_if_fail (ADW_IS_BIN (self));
   g_return_if_fail (child == NULL || GTK_IS_WIDGET (child));
 
+  if (child)
+    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
+
   priv = adw_bin_get_instance_private (self);
 
   if (priv->child == child)
