@@ -19,7 +19,7 @@
 /**
  * AdwBreakpoint:
  *
- * Describes a breakpoint for [class@Window] or [class@Dialog].
+ * Describes a breakpoint for [class@Window].
  *
  * Breakpoints are used to create adaptive UI, allowing to change the layout
  * depending on available size.
@@ -35,8 +35,8 @@
  * For more complicated scenarios, [signal@Breakpoint::apply] and
  * [signal@Breakpoint::unapply] can be used instead.
  *
- * Breakpoints can be used within [class@Window], [class@ApplicationWindow],
- * [class@Dialog] or [class@BreakpointBin].
+ * Breakpoints can be used within [class@Window], [class@ApplicationWindow] or
+ * [class@BreakpointBin].
  *
  * ## `AdwBreakpoint` as `GtkBuildable`:
  *
@@ -642,7 +642,6 @@ parse_multi (const char            *str,
       return cond_1;
     } else {
       *error = CONDITION_PARSER_ERROR_UNKNOWN_OPERATOR;
-      g_clear_pointer (&cond_1, adw_breakpoint_condition_free);
       return NULL;
     }
 
@@ -651,7 +650,6 @@ parse_multi (const char            *str,
     } else {
       *endp = (char *) str;
       *error = CONDITION_PARSER_ERROR_UNEXPECTED_CHARACTER;
-      g_clear_pointer (&cond_1, adw_breakpoint_condition_free);
       return NULL;
     }
 
@@ -665,7 +663,6 @@ parse_multi (const char            *str,
 
       if (!cond_2) {
         *endp = (char *) str;
-        g_clear_pointer (&cond_1, adw_breakpoint_condition_free);
         return NULL;
       }
 
@@ -682,7 +679,6 @@ parse_multi (const char            *str,
 
     if (!cond_2) {
       *endp = (char *) str;
-      g_clear_pointer (&cond_1, adw_breakpoint_condition_free);
       return NULL;
     }
 
@@ -1114,7 +1110,7 @@ adw_breakpoint_class_init (AdwBreakpointClass *klass)
   object_class->set_property = adw_breakpoint_set_property;
 
   /**
-   * AdwBreakpoint:condition:
+   * AdwBreakpoint:condition: (attributes org.gtk.Property.get=adw_breakpoint_get_condition org.gtk.Property.set=adw_breakpoint_set_condition)
    *
    * The breakpoint's condition.
    *
@@ -1482,7 +1478,7 @@ adw_breakpoint_new (AdwBreakpointCondition *condition)
 }
 
 /**
- * adw_breakpoint_get_condition:
+ * adw_breakpoint_get_condition: (attributes org.gtk.Method.get_property=condition)
  * @self: a breakpoint
  *
  * Gets the condition for @self.
@@ -1500,7 +1496,7 @@ adw_breakpoint_get_condition (AdwBreakpoint *self)
 }
 
 /**
- * adw_breakpoint_set_condition:
+ * adw_breakpoint_set_condition: (attributes org.gtk.Method.set_property=condition)
  * @self: a breakpoint
  * @condition: (nullable): the new condition
  *
@@ -1538,12 +1534,11 @@ adw_breakpoint_set_condition (AdwBreakpoint          *self,
  * applying the breakpoint, and set it back to its original value upon
  * unapplying it.
  *
- * ::: note
- *     Setting properties to their original values does not work for properties
- *     that have irreversible side effects. For example, changing
- *     [property@Gtk.Button:label] while [property@Gtk.Button:icon-name] is set
- *     will reset the icon. However, resetting the label will not set
- *     `icon-name` to its original value.
+ * Note that setting properties to their original values does not work for
+ * properties that have irreversible side effects. For example, changing
+ * [property@Gtk.Button:label] while [property@Gtk.Button:icon-name] is set will
+ * reset the icon. However, resetting the label will not set icon-name to its
+ * original value.
  *
  * Use the [signal@Breakpoint::apply] and [signal@Breakpoint::unapply] signals
  * for those properties instead, as follows:
